What is ASTK?
===============

**ASTK** is a command-line software for comprehensive alternative splicing analysis including:
- characterizing distribution and expression patterns of alternative splicing events
- systematically analyzing functional effects of AS events at the gene- and exon-level respectively
- dissecting out splicing-associated sequence features and epigenetic marks
- inferring the splicing regulatory code for each type of AS. 

<img src='https://huang-sh.github.io/astk-doc/static/img/workflow.png' alt="workflow.png"></img>

Documentation
===============

The documentation for ***ASTK*** is available on [astk-doc](https://huang-sh.github.io/astk-doc/)


Contact
===============
If you have any problem, contact me at hsh-me@outlook.com
